@@ -7,7 +7,11 @@ use File::Slurp 'read_file';
 use Text::Hunspell;
 use v5.14;
 
-use version; our $VERSION = qv('0.0.3'); # First version elaborated from old one
+use version; our $VERSION = qv('0.0.4'); # First version elaborated from old one
+
+use base 'Test::Builder::Module';
+
+my $CLASS = __PACKAGE__;
 our $word_re = qr/([\w\'áéíóúÁÉÍÓÚñÑ]+)/;
 
 # Module implementation here
@@ -51,24 +55,24 @@ sub files {
 
 sub check {
   my $self = shift;
+  my $tb= $CLASS->builder;
   my $speller = $self->{'_speller'};
-  my $count = 1;
   for my $f ( @{$self->files}) {
     my $file_content =read_file($f);
     my @words = split /\s+/, $file_content;
+
     for my $w (@words) {
       my ($stripped_word) = ( $w =~ $word_re );
       next if !$stripped_word;
-      if  ( $speller->check( $stripped_word) ) {
-	print "ok ";
-      } else {
-	print "not ok ";
-      }
-      say $count++," - $stripped_word";
+      $tb->ok( $speller->check( $stripped_word),  " $stripped_word");
     }
   }
 }
 
+sub done_testing {
+  my $tb= $CLASS->builder;
+  $tb->done_testing;
+}
 
 "All over, all out, all over and out"; # Magic circus phrase said at the end of the show
 
@@ -97,6 +101,8 @@ This document describes Test::Text version 0.0.3
 
    $testxt->check(); # spell-checks plain or markdown text in that dir or just passed
 
+   $testxt->done_testing(); # all over and out
+
 
 =head1 DESCRIPTION
 
@@ -128,13 +134,27 @@ object, it is useful for other functions.
 
 Check defined files
 
+=head2 done_testing
+
+Called after all tests have been performed
+
 =head1 DEPENDENCIES
 
 Test::Text requires L<Text::Hunspell> and the 
 C<en_US> dictionnary for C<hunspell>, which you can install with
 C<sudo apt-get install hunspell-en-us> , but since I found no way of expressing this
 dependency within Makefile.PL, I have added it to the C<data> dir,
-mainly
+mainly. Latest version requires L<Test::Builder>.
+
+=head1 Development and bugs
+
+Development of this module is hosted at L<GitHub|http://github.com/JJ/Test-Text>. Use it for forking, bug reports, checking it out, whatever
+
+=head1 SEE ALSO
+
+L<Manuel, the Marvelous Mechanical Man|https://www.amazon.com/Manuel-Magnificent-Mechanical-Logical-Natural-History-ebook/dp/B00ED084BK/ref=as_li_ss_til?tag=perltutobyjjmere&linkCode=w01&linkId=4PA3TNKRGGBZKHOE&creativeASIN=B00ED084BK>, the novel that spawned all this, or the other way around. 
+
+
 
 =head1 AUTHOR
 
